<?php 

namespace Advally\Advertising;

use XF;
use XF\Util\File;

class Adstxt {


	static public function isWriteable() {

		// Get the local path for ads.txt
		$path = self::getWebrootAdstxtPath();

		// Returns if the path is writeable
		return File::isWritable($path) ? 1 : 0;
	}

	static public function cronUpdate() {

		// Details we may need from XF 
		$options = XF::options();

		// Only update ads.txt if the plugin is enabled and set to manage ads.txt
		if ($options->advally_enable && $options->advally_adstxt_management == 'automatic') {
			self::updateNow();
		}

	}

	static public function updateNow() {

		// Details we may need from XF 
		$options = XF::options();

		// Get the Ads.txt contents
		$contents = self::getAdstxtContents($options);

		// Get the local path for ads.txt
		$path = self::getWebrootAdstxtPath();

		// Write the contents, if possible 
		if (File::isWritable($path)) {
			\XF::logError(sprintf('Ads.txt successfully updated to %s', $path));
			return self::updateAdstxtContents($path, $contents);
		} else {
			\XF::logError(sprintf('Error updating Ads.txt.  Cannot write to %s', $path));
			return false;
		}
	
	}

	static public function getWebrootAdstxtPath() {
		return sprintf("%s/ads.txt", $_SERVER["DOCUMENT_ROOT"]);
	}

	static private function updateAdstxtContents($path, $contents) {

		// Backup the existing adstxt file
		if (file_exists($path)) {
			$backupName = File::getNamedTempFile(sprintf("adstxt-backup-%s.txt", time()), false);
			$res = \XF\Util\File::copyFile($path, $backupName, false);
		} 

		// Write the contents 

		return \XF\Util\File::writeFile($path, $contents, false);
	}

	static private function getAdstxtContents($options) {

		// Get the contents from Advally based on Alias
		$contents = self::getAdvallyAdstxt($options->advally_alias);

		// Append any addtional lines
		if (!empty($options->advally_adstxt_addlines)) {
			$contents .= "\n\n#\n# Self Managed Ads.txt lines\n#\n" . $options->advally_adstxt_addlines;
		}

		return $contents;
	}

	static private function getAdvallyAdstxt($siteID) {
	
		$url = sprintf("https://cdn.adligature.com/%s/ads.txt", $siteID);

		// Use CURL to download the contents
		$curl = curl_init();
		curl_setopt($curl, CURLOPT_RETURNTRANSFER, true);
	    curl_setopt($curl, CURLOPT_URL, $url);
		$contents = curl_exec($curl);
	    curl_close($curl);

		return $contents;
	}

}
