<?php 

namespace Advally\Advertising;

use XF;

class Helpers {

	const EXPERIENCE_ADFREE = 'adfree';
	const EXPERIENCE_LIGHT = 'light';
	const EXPERIENCE_NORMAL = 'normal';
	const EXPERIENCE_NASCAR = 'nascar';

	const FORMAT_BANNER = 'banner';
	const FORMAT_VIDEO = 'video';
	const FORMAT_RECIRCULATION = 'recirculation';
	const FORMAT_QUIZ = 'quiz';

	/*
	<xf:set var="$adFormat">
	<xf:callback class="Advally\Advertising\Helpers" method="getThreadFormat" params="['test1','test2',{$post.position}]">{{$xf.visitor.user_id}}</xf:callback>
	</xf:set>
	*/

	static public function getForumListFormat(string $innerText, Array $params, Object $Object) 
	{
		// Current post position 
		$curPosition = $params[0];

		// Details we may need from XF 
		$options = XF::options();

		// Default settings. These will be overridden basd on user type 
		$experience = self::getUserExperience();
		$frequency = null;

		// Ad Free experience
		if ($experience == self::EXPERIENCE_ADFREE) {
			return null;
		}

		// determine position based on experience
		$frequency = $options->{'advally_adexp_'.$experience.'_forum_list_frequency'};

		if ($curPosition % $frequency == 0)
			return self::FORMAT_BANNER;

	}

	static public function getForumViewFormat(string $innerText, Array $params, Object $Object) 
	{
		// Current post position 
		$curPosition = $params[0];

		// Details we may need from XF 
		$options = XF::options();

		// Default settings. These will be overridden basd on user type 
		$experience = self::getUserExperience();
		$frequency = null;
		$start_top = 0;

		// Ad Free experience
		if ($experience == self::EXPERIENCE_ADFREE) {
			return null;
		}

		// determine position based on experience
		$frequency = $options->{'advally_adexp_'.$experience.'_forum_view_frequency'};
		$start_top = $options->{'advally_adexp_'.$experience.'_forum_view_start_top'};
		$offset = $start_top['enabled'] ? $start_top['offset'] : 0;

		if ($curPosition == $offset)
			return self::FORMAT_BANNER;
		else if ($curPosition > $offset && $curPosition % $frequency == $offset)
			return self::FORMAT_BANNER;

	}

	static public function getThreadFormat(string $innerText, Array $params, Object $Object) 
	{

		// Details we may need from XF 
		$options = XF::options();
		
		// Current post position on this page 
		$curPosition = (int)$params[0] % $options->messagesPerPage;
		
		// Default settings. These will be overridden basd on user type 
		$experience = self::getUserExperience();
		$frequency = null;
		$premium = [
			self::FORMAT_VIDEO => null, 
			self::FORMAT_RECIRCULATION => null,
			self::FORMAT_QUIZ => null, 
		];


		// Ad Free experience
		if ($experience == self::EXPERIENCE_ADFREE) {
			return null;
		}

		// determine position based on experience
		$frequency = $options->{'advally_adexp_'.$experience.'_thread_frequency'};
		$premium[self::FORMAT_VIDEO] = $options->{'advally_adexp_'.$experience.'_'.self::FORMAT_VIDEO};
		$premium[self::FORMAT_RECIRCULATION] = $options->{'advally_adexp_'.$experience.'_'.self::FORMAT_RECIRCULATION};
		$premium[self::FORMAT_QUIZ] = $options->{'advally_adexp_'.$experience.'_'.self::FORMAT_QUIZ};

		// Check premium formats first
		foreach ($premium as $format => $settings) {
			if ($settings['position']-1 == $curPosition) {
				return $format;
			}
		}
		
		// Return a banner 
		if ($curPosition == 0 || ($curPosition+1) % $frequency == 0) {
			return self::FORMAT_BANNER;
		}
	}

	static public function getBehavior(string $innerText, Array $params, Object $Object) 
	{
		// Config key for the requested behavior
		$behaviorKey = trim($innerText);

		// Details we may need from XF 
		$options = XF::options();

		// Default settings. These will be overridden basd on user type 
		$experience = self::getUserExperience();
		
		// Ad Free experience
		if ($experience == self::EXPERIENCE_ADFREE) {
			return 'false';
		}

		// determine position based on experience
		$options = $options->{'advally_adexp_'.$experience.'_behaviors'};
		
		if (array_key_exists($behaviorKey, $options)) {
			return $options[$behaviorKey]=="1" ? 'true' : 'false'; // 1 : 0;
		}
		
		return 'false';
	}

	static public function getPhraseLink(string $innerText, Array $params, Object $Object)
	{
		$router = XF::app()->router('public');

		$link = $router->buildLink( $params[0] );

		return str_replace('{link}', $link, $innerText);
	}

	static public function getUserExperience()
	{

		$options = XF::options();
		$visitor = XF::visitor();
		
		$experience = null;

		// Lookup the experience for this user
		if ($visitor->user_id == 0) {
			$experience = $options->advally_experience_guests;
		} else {
			if ($visitor->isMemberOf($options->advally_experience_premium_groups)) {
				$experience = $options->advally_experience_premium;
			} else {
				$experience = $options->advally_experience_members;
			}
		}
		
		return $experience;
	}	

}
